#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dotgen
version:              0.4.3
visibility:           public
id:                   dotgen-0.4.3-CYDj58Mb9IBFJpxulglUb5
key:                  dotgen-0.4.3-CYDj58Mb9IBFJpxulglUb5
license:              BSD-3-Clause
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            alpha
homepage:             https://github.com/ku-fpg/dotgen
synopsis:             A simple interface for building .dot graph files.
description:
    This package provides a simple interface for building .dot graph files,
    for input into the dot and graphviz tools.
    It includes a monadic interface for building graphs.

category:             Text
abi:                  4dd365144c4bd274734372480675fb02
exposed:              True
exposed-modules:      Text.Dot
import-dirs:          /usr/lib/ghc-8.10.5/site-local/dotgen-0.4.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dotgen-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/dotgen-0.4.3
hs-libraries:         HSdotgen-0.4.3-CYDj58Mb9IBFJpxulglUb5
depends:              base-4.14.2.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-dotgen/html/dotgen.haddock
haddock-html:         /usr/share/doc/haskell-dotgen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

